/*****************************************************************************
 * Copyright (C) 2013-2018 Radian Memory Systems
 *
 * This file is provided under non-disclosure agreement.
 * See the file COPYING for details.
 ******************************************************************************/
#ifndef RMS_NVMEXPRESS_VENDOR_H
#define RMS_NVMEXPRESS_VENDOR_H

#define NVM_RMS_VENDOR_RMS200       0xd8
#define NVM_RMS_VENDOR_WRITE        0xd9

typedef enum {
    RMS_GET_HW_INFO = 0x01,
    RMS_RW_I2C,
    RMS_RW_LEDS,
    RMS_SET_DMI_WINBASE,
    RMS_GET_DMI_WINBASE,
    RMS_SET_DMI_WINSIZE,
    RMS_RESET_I2C,
    RMS_CLEAN_SHDN_NVRAM_SAVED,
    RMS_CLEAN_SHDN_NVRAM_ERASED,
    RMS_F2F,
    RMS_RESTORE,
    RMS_GET_DIALOG_CFG,
    RMS_SET_DIALOG_CFG,
} rms_opcodes_e;

#define SYS_DEBUG_DIALOG_CTRL 0x07

typedef struct
{
    u32 offset; /* DW13 */
    u32 val; /* DW14 */
    u8 slaveAddr; /* DW 15 */
    u8 i2c_op;
    u8 len;
    u8 resvd;
} rms_i2c_params_t;

typedef struct
{
    u32 flags; /* DW13 */
} rms_f2f_params_t;


#define LED_OP_WRITE  0
#define LED_OP_READ  1

typedef struct
{
    u16 led_op; /* DW13 */
    u16 on_off_mask; /* DW13 */
    u16 fast_blink_mask; /* DW14 */
    u16 slow_blink_mask; /* DW14 */
} rms_led_params_t;

typedef struct
{
    u32 winsize_mb; /* DW13 */
} rms_dmi_winsize_params_t;

typedef struct
{
    u32 winbase_mb; /* DW13 */
} rms_dmi_winbase_params_t;
/**
 * @brief NVMe vendor specific command: RMS-200 
 */
typedef struct
{
    /**
     * @brief DWORD 10: Number of Dword in PRP
     */
    u32 numOfDwordPrP;
    /**
     * @brief DWORD 11: Number of Dword in MPTR
     */
    u32 numOfDwordMptr;
    /**
     * @brief DWORD12: Subcommand opcode
     */
    u32 subOpcode : 16;
    u32 reserved  : 16;
    /**
     * @brief Subcommand definition
     */
    union
    {
        rms_i2c_params_t            i2c_params;
        rms_led_params_t            led_params;
        rms_dmi_winsize_params_t    winsize_params;
        rms_dmi_winbase_params_t    winbase_params;
        rms_f2f_params_t            f2f_params;
    };
} nvme_cmd_rms200_t;

#endif /* RMS_NVMEXPRESS_VENDOR_H */

